#======
# Copyright (c) IBM Corp. 2011, 2014.
# All rights reserved. This program is made available
# under the terms of the Eclipse Public License v1.0
# which accompanies this distribution, and is available at
# http://www.eclipse.org/legal/epl-v10.html
#=======


#
# IMPORTS
#
from snack import *
from model.config import STR_VERSION

from viewer.__data__ import ARE_YOU_SURE_YOU_WANTO_TO
from viewer.__data__ import OK
from viewer.__data__ import IBM_POWERKVM
from viewer.__data__ import BACK


#
# CONSTANTS
#


#
# CODE
#
class Confirmation:
    """
    Confirm the last option
    """

    def __init__(self, screen, device, diskData, lvmData):
        """
        Constructor

        @type  screen: SnackScreen
        @param screen: SnackScreen instance
        """

        self.__screen = screen
        self.__lvmData = lvmData
        self.__diskData = diskData
        self.__selectedDisk = device

        parts, vgs = self.__getSummary()
        if not vgs:
            vgs = ' '

        if not parts:
            parts = ' '

        self.__msg = TextboxReflowed(60, ARE_YOU_SURE_YOU_WANTO_TO.localize() % (device, parts, vgs))
        self.__buttonsBar = ButtonBar(self.__screen, [(OK.localize(), "ok"),
            (BACK.localize(), "back")])

        self.__grid = GridForm(self.__screen, IBM_POWERKVM.localize() % STR_VERSION, 1, 3)
        self.__grid.add(self.__msg, 0, 1)
        self.__grid.add(self.__buttonsBar, 0, 2)

    # __init__()

    def run(self):
        """
        Draws the screen

        @rtype: boolean
        @returns: sucess status
        """

        result = self.__grid.run()
        self.__screen.popWindow()

        rc = self.__buttonsBar.buttonPressed(result)

        return rc == "ok"
    # run()

    def __belongsToVG(self, partition, default):
        """
        Checks if partition belongs to a LVM and returns its VG name

        @type partition: str
        @param partition: partition name

        @type default: arbitrary
        @param default: value to return case no VG found

        @rtype: str
        @returns: VG name or default
        """
        # no lvm data: return default
        if not self.__lvmData or not 'vgs' in self.__lvmData:
            return default

        # return the VG name for the given partition
        for vg, details in self.__lvmData['vgs'].iteritems():
            for partitions in details['pvsToLvs']:
                if partition in partitions:
                    return vg

        # nothing found: return default
        return default
    # __belongsToVG()

    def __getSummary(self):
        """
        Formats the data about partitioning layout to be displayed
        in the disk selection screen

        @rtype:   dict
        @returns: partitoning layout
        """
        partitionsToBeRemoved = []
        vgsToBeRemoved = []

        dname = self.__selectedDisk.split('/')[-1]
        for disk in self.__diskData:
            name = disk['name'] if not disk['mpath_master'] \
                   else disk['mpath_master']

            # skip if it's not the disk we are looking for
            if name != dname:
                continue

            for partition in disk['parts']:
                # format the partition name correctly
                number = str(partition['nr'])
                partname = '%s%s' % (name, number)

                # no partition in disk
                if number == '0':
                    partname = ' '

                # append the partition name found
                else:
                    partitionsToBeRemoved.append(partname)

                    # append the VG name if found
                    if partition['fs'] == 'lvm':
                        vg = self.__belongsToVG(partname, None)
                        if vg:
                            vgsToBeRemoved.append(vg)

            # multipath can have more than one disk with same
            # name but we don't want to print evertyhing more
            # than once
            break

        return (','.join(partitionsToBeRemoved), ','.join(vgsToBeRemoved))
    # __getSummary()
# SelectHardDisk
