#!/usr/bin/python

#======
# Copyright (c) IBM Corp. 2011, 2014.
# All rights reserved. This program is made available
# under the terms of the Eclipse Public License v1.0
# which accompanies this distribution, and is available at
# http://www.eclipse.org/legal/epl-v10.html
#=======



#
# IMPORTS
#
from snack import *
from model.config import STR_VERSION
from model.config import IBMPKVM_TARBALL_ERROR_LOG
from viewer.__data__ import OK
from viewer.__data__ import IBM_POWERKVM
from viewer.__data__ import PKVM_ERROR_MSG
from viewer.__data__ import PKVM_LOG_MSG
from viewer.__data__ import IBMPKVMERROR_ERROR
from viewer.__data__ import IBMPKVMERROR_UNKNOWN


#
# CONSTANTS
#


#
# CODE
#
class GeneralTopError:
    """
    Screen when hardware is not entitled
    """

    def __init__(self, screen):
        """
        Constructor

        @type  screen: SnackScreen
        @param screen: SnackScreen instance
        """
        self.__screen = screen
        self.__title = IBM_POWERKVM.localize() % STR_VERSION

        self.__msg = PKVM_ERROR_MSG.localize() % IBMPKVMERROR_ERROR.localize()
        self.__errorMsg = IBMPKVMERROR_UNKNOWN.localize()
        self.__logMsg = PKVM_LOG_MSG.localize() % IBMPKVM_TARBALL_ERROR_LOG
    # __init__()

    def run(self, code = []):
        """
        Displays an error when there is any error during installation

        @type code: str
        @param code: error code

        @rtype: nothing
        @returns: nothing
        """
        if len(code) == 2:
            msg = PKVM_ERROR_MSG.localize() % code[0]
            errorMsg = code[1]
        else:
            msg = self.__msg
            errorMsg = self.__errorMsg

        table = []
        table.append(msg)
        table.append(errorMsg)
        table.append(self.__logMsg)

        ButtonChoiceWindow(self.__screen, self.__title,
                '\n'.join(table),
                buttons=[(OK.localize(), 'ok')],
                width = 50)
    # run()

# GeneralTopError
